# kudu
[![Build Status](https://travis-ci.org/torfeld6/kudu.svg?branch=master)](https://travis-ci.org/torfeld6/kudu) [![codebeat badge](https://codebeat.co/badges/be7de81c-c082-41ad-ba1d-ca5ee2d0b07a)](https://codebeat.co/projects/github-com-torfeld6-kudu-master) [![Coverage Status](https://coveralls.io/repos/github/torfeld6/kudu/badge.svg?branch=master)](https://coveralls.io/github/torfeld6/kudu?branch=master)

## Release History
### 0.5 (2019-06-17)
- requires requests >= 2.20.1